pub struct PreprocessorOutput {
pub text_elements: Vec<PdfTextElement>,
pub metadata: DocumentMetadata,
pub style_data: StyleData,
pub bookmark_data: Option<BookmarkData>,
}Expand description
Complete output from document preprocessing
Contains all the data extracted from document parsing, including text elements, metadata, styling information, and document structure.
Fields
text_elements: Vec<PdfTextElement>Extracted text elements with positioning and styling
metadata: DocumentMetadataDocument metadata (title, author, creation date, etc.)
style_data: StyleDataStyle information (fonts, colors, formatting)
bookmark_data: Option<BookmarkData>Document bookmarks/table of contents (if available)